Package: HCATonsilData
Title: Provide programmatic access to the tonsil cell atlas datasets
Version: 1.9.0
Authors@R: c(person("Ramon", "Massoni-Badosa", role = c("aut", "cre"),
                    email ="ramonmassoni@gmail.com",
                    comment = c(ORCID = "0000-0001-7115-8145")),
             person("Federico", "Marini", role = c("aut"),
                    email = "marinif@uni-mainz.de", 
                    comment = c(ORCID = "0000-0003-3252-7758")),
             person("Alan", "O'Callaghan", role = c("aut"),
                    email = "alan.ocallaghan@outlook.com"),
	           person("Helena L.", "Crowell", role=c("aut"),
	                  email="helena@crowell.eu", 
	                  comment = c(ORCID="0000-0002-4801-1767"))
             )
Description: This package provides access to the scRNA-seq, scATAC-seq,
    multiome, CITE-seq and spatial transcriptomics (Visium) data generated
    by the tonsil cell atlas in the context of the Human Cell Atlas (HCA).
    The data is provided via the Bioconductor project in the form of 
    SingleCellExperiments. Additionally, information on the whole compendium of
    identified cell types is provided in form of a glossary.
License: MIT + file LICENSE
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Imports: ExperimentHub, SingleCellExperiment, SpatialExperiment,
        HDF5Array, SummarizedExperiment, S4Vectors, htmltools,
        rmarkdown, base64enc, utils
Suggests: knitr, ggplot2, testthat (>= 3.0.0), scater, Seurat, Signac,
        zellkonverter, iSEE, ggspavis, kableExtra, BiocStyle
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://github.com/massonix/HCATonsilData
BugReports: https://github.com/massonix/HCATonsilData/issues
biocViews: SingleCellData, ExperimentData, RNASeqData, ExperimentHub,
        ExpressionData, SpatialData
Depends: R (>= 4.3.0)
git_url: https://git.bioconductor.org/packages/HCATonsilData
git_branch: devel
git_last_commit: 3cdd05d
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 16:24:14 UTC; biocbuild
Author: Ramon Massoni-Badosa [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7115-8145>),
  Federico Marini [aut] (ORCID: <https://orcid.org/0000-0003-3252-7758>),
  Alan O'Callaghan [aut],
  Helena L. Crowell [aut] (ORCID:
    <https://orcid.org/0000-0002-4801-1767>)
Maintainer: Ramon Massoni-Badosa <ramonmassoni@gmail.com>
