# Generated by roxygen2: do not edit by hand

export(HCATonsilData)
export(TonsilData_cellinfo)
export(TonsilData_cellinfo_html)
export(TonsilData_glossary)
export(listCellTypes)
export(updateAnnotation)
importFrom(ExperimentHub,ExperimentHub)
importFrom(HDF5Array,HDF5Array)
importFrom(S4Vectors,DataFrame)
importFrom(SingleCellExperiment,"reducedDim<-")
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SingleCellExperiment,reducedDim)
importFrom(SingleCellExperiment,reducedDims)
importFrom(SpatialExperiment,SpatialExperiment)
importFrom(SpatialExperiment,SpatialImage)
importFrom(SummarizedExperiment,assay)
importFrom(base64enc,dataURI)
importFrom(htmltools,tags)
importFrom(rmarkdown,render)
importFrom(utils,browseURL)
importFrom(utils,read.table)
